@@ -19,10 +19,12 @@ package org.apache.maven.plugins.surefire.report;
  * under the License.
  */
 
+import org.apache.maven.doxia.markup.HtmlMarkup;
+import org.apache.maven.doxia.sink.Sink;
+import org.apache.maven.doxia.sink.SinkEventAttributeSet;
+import org.apache.maven.doxia.sink.SinkEventAttributes;
 import org.apache.maven.reporting.MavenReportException;
-import org.codehaus.doxia.sink.Sink;
 
-import java.io.File;
 import java.text.NumberFormat;
 import java.util.Iterator;
 import java.util.List;
@@ -32,17 +34,20 @@ import java.util.Map;
 import java.util.ResourceBundle;
 import java.util.StringTokenizer;
 
+/**
+ * @version $Id: SurefireReportGenerator.java 1076592 2011-03-03 11:36:07Z ltheussl $
+ */
 public class SurefireReportGenerator
 {
-    private SurefireReportParser report;
+    private final SurefireReportParser report;
 
     private List testSuites;
 
-    private boolean showSuccess;
+    private final boolean showSuccess;
 
-    private String xrefLocation;
+    private final String xrefLocation;
 
-    public SurefireReportGenerator( File[] reportsDirectories, Locale locale, boolean showSuccess, String xrefLocation )
+    public SurefireReportGenerator( List reportsDirectories, Locale locale, boolean showSuccess, String xrefLocation )
     {
         report = new SurefireReportParser( reportsDirectories, locale );
 
@@ -62,30 +67,16 @@ public class SurefireReportGenerator
         sink.text( bundle.getString( "report.surefire.header" ) );
         sink.title_();
 
-        StringBuffer str = new StringBuffer();
-        str.append( "<script type=\"text/javascript\">\n" );
-        str.append( "function toggleDisplay(elementId) {\n" );
-        str.append( " var elm = document.getElementById(elementId + 'error');\n" );
-        str.append( " if (elm && typeof elm.style != \"undefined\") {\n" );
-        str.append( " if (elm.style.display == \"none\") {\n" );
-        str.append( " elm.style.display = \"\";\n" );
-        str.append( " document.getElementById(elementId + 'off').style.display = \"none\";\n" );
-        str.append( " document.getElementById(elementId + 'on').style.display = \"inline\";\n" );
-        str.append( " }" );
-        str.append( " else if (elm.style.display == \"\") {" );
-        str.append( " elm.style.display = \"none\";\n" );
-        str.append( " document.getElementById(elementId + 'off').style.display = \"inline\";\n" );
-        str.append( " document.getElementById(elementId + 'on').style.display = \"none\";\n" );
-        str.append( " } \n" );
-        str.append( " } \n" );
-        str.append( " }\n" );
-        str.append( "</script>" );
-        sink.rawText( str.toString() );
-
         sink.head_();
 
         sink.body();
 
+        SinkEventAttributeSet atts = new SinkEventAttributeSet();
+        atts.addAttribute( SinkEventAttributes.TYPE, "text/javascript" );
+        sink.unknown( "script", new Object[]{new Integer( HtmlMarkup.TAG_TYPE_START )}, atts );
+        sink.unknown( "cdata", new Object[]{new Integer( HtmlMarkup.CDATA_TYPE ), javascriptToggleDisplayCode() }, null );
+        sink.unknown( "script", new Object[]{new Integer( HtmlMarkup.TAG_TYPE_END )}, null );
+
         sink.section1();
         sink.sectionTitle1();
         sink.text( bundle.getString( "report.surefire.header" ) );
@@ -111,8 +102,6 @@ public class SurefireReportGenerator
             constructFailureDetails( sink, bundle, failureList );
         }
 
-        sinkLineBreak( sink );
-
         sink.body_();
 
         sink.flush();
@@ -126,13 +115,11 @@ public class SurefireReportGenerator
 
         sink.section1();
         sink.sectionTitle1();
+        sink.text( bundle.getString( "report.surefire.label.summary" ) );
+        sink.sectionTitle1_();
 
         sinkAnchor( sink, "Summary" );
 
-        sink.text( bundle.getString( "report.surefire.label.summary" ) );
-
-        sink.sectionTitle1_();
-
         constructHotLinks( sink, bundle );
 
         sinkLineBreak( sink );
@@ -175,7 +162,9 @@ public class SurefireReportGenerator
 
         sink.lineBreak();
 
-        sink.rawText( bundle.getString( "report.surefire.text.note1" ) );
+        sink.paragraph();
+        sink.text( bundle.getString( "report.surefire.text.note1" ) );
+        sink.paragraph_();
 
         sinkLineBreak( sink );
 
@@ -188,13 +177,11 @@ public class SurefireReportGenerator
 
         sink.section1();
         sink.sectionTitle1();
+        sink.text( bundle.getString( "report.surefire.label.packagelist" ) );
+        sink.sectionTitle1_();
 
         sinkAnchor( sink, "Package_List" );
 
-        sink.text( bundle.getString( "report.surefire.label.packagelist" ) );
-
-        sink.sectionTitle1_();
-
         constructHotLinks( sink, bundle );
 
         sinkLineBreak( sink );
@@ -252,7 +239,9 @@ public class SurefireReportGenerator
 
         sink.lineBreak();
 
-        sink.rawText( bundle.getString( "report.surefire.text.note2" ) );
+        sink.paragraph();
+        sink.text( bundle.getString( "report.surefire.text.note2" ) );
+        sink.paragraph_();
 
         packIter = suitePackages.keySet().iterator();
 
@@ -266,13 +255,11 @@ public class SurefireReportGenerator
 
             sink.section2();
             sink.sectionTitle2();
+            sink.text( packageName );
+            sink.sectionTitle2_();
 
             sinkAnchor( sink, packageName );
 
-            sink.text( packageName );
-
-            sink.sectionTitle2_();
-
             sink.table();
 
             sink.tableRow();
@@ -366,13 +353,11 @@ public class SurefireReportGenerator
 
         sink.section1();
         sink.sectionTitle1();
+        sink.text( bundle.getString( "report.surefire.label.testcases" ) );
+        sink.sectionTitle1_();
 
         sinkAnchor( sink, "Test_Cases" );
 
-        sink.text( bundle.getString( "report.surefire.label.testcases" ) );
-
-        sink.sectionTitle1_();
-
         constructHotLinks( sink, bundle );
 
         ListIterator suiteIterator = testSuites.listIterator();
@@ -383,19 +368,17 @@ public class SurefireReportGenerator
 
             List testCases = suite.getTestCases();
 
-            if ( testCases != null )
+            if ( testCases != null && !testCases.isEmpty() )
             {
                 ListIterator caseIterator = testCases.listIterator();
 
                 sink.section2();
                 sink.sectionTitle2();
+                sink.text( suite.getName() );
+                sink.sectionTitle2_();
 
                 sinkAnchor( sink, suite.getPackageName() + suite.getName() );
 
-                sink.text( suite.getName() );
-
-                sink.sectionTitle2_();
-
                 sink.table();
 
                 while ( caseIterator.hasNext() )
@@ -431,17 +414,31 @@ public class SurefireReportGenerator
 
                             sinkLink( sink, testCase.getName(), "#" + testCase.getFullName() );
 
-                            sink.rawText( "  <div class=\"detailToggle\" style=\"display:inline\">" );
+                            SinkEventAttributeSet atts = new SinkEventAttributeSet();
+                            atts.addAttribute( SinkEventAttributes.CLASS, "detailToggle" );
+                            atts.addAttribute( SinkEventAttributes.STYLE, "display:inline" );
+                            sink.unknown( "div", new Object[]{new Integer( HtmlMarkup.TAG_TYPE_START )}, atts );
 
-                            sink.link( "javascript:toggleDisplay('" + testCase.getName() + "');" );
+                            sink.link( "javascript:toggleDisplay('" + toHtmlId( testCase.getFullName() ) + "');" );
+
+                            atts = new SinkEventAttributeSet();
+                            atts.addAttribute( SinkEventAttributes.STYLE, "display:inline;" );
+                            atts.addAttribute( SinkEventAttributes.ID, toHtmlId( testCase.getFullName() ) + "off" );
+                            sink.unknown( "span", new Object[]{new Integer( HtmlMarkup.TAG_TYPE_START )}, atts );
+                            sink.text( " + " );
+                            sink.unknown( "span", new Object[]{new Integer( HtmlMarkup.TAG_TYPE_END )}, null );
+
+                            atts = new SinkEventAttributeSet();
+                            atts.addAttribute( SinkEventAttributes.STYLE, "display:none;" );
+                            atts.addAttribute( SinkEventAttributes.ID, toHtmlId( testCase.getFullName() ) + "on" );
+                            sink.unknown( "span", new Object[]{new Integer( HtmlMarkup.TAG_TYPE_START )}, atts );
+                            sink.text( " - " );
+                            sink.unknown( "span", new Object[]{new Integer( HtmlMarkup.TAG_TYPE_END )}, null );
 
-                            sink.rawText( "<span style=\"display: inline;\" " + "id=\"" + testCase.getName() +
-                                "off\">+</span><span id=\"" + testCase.getName() + "on\" " +
-                                "style=\"display: none;\">-</span> " );
                             sink.text( "[ Detail ]" );
                             sink.link_();
 
-                            sink.rawText( "</div>" );
+                            sink.unknown( "div", new Object[]{new Integer( HtmlMarkup.TAG_TYPE_END )}, null );
 
                             sink.tableCell_();
                         }
@@ -471,12 +468,14 @@ public class SurefireReportGenerator
                                 sinkCell( sink, "" );
 
                                 sink.tableCell();
-                                sink.rawText(
-                                    "  <div id=\"" + testCase.getName() + "error\" style=\"display:none;\">" );
+                                SinkEventAttributeSet atts = new SinkEventAttributeSet();
+                                atts.addAttribute( SinkEventAttributes.ID, toHtmlId( testCase.getFullName() ) + "error" );
+                                atts.addAttribute( SinkEventAttributes.STYLE, "display:none;" );
+                                sink.unknown( "div", new Object[]{new Integer( HtmlMarkup.TAG_TYPE_START )}, atts );
 
                                 Iterator it = detail.iterator();
 
-                                sink.verbatim( true );
+                                sink.verbatim( null );
                                 while ( it.hasNext() )
                                 {
                                     sink.text( it.next().toString() );
@@ -484,7 +483,7 @@ public class SurefireReportGenerator
                                 }
                                 sink.verbatim_();
 
-                                sink.rawText( "</div>" );
+                                sink.unknown( "div", new Object[]{new Integer( HtmlMarkup.TAG_TYPE_END )}, null );
                                 sink.tableCell_();
 
                                 sinkCell( sink, "" );
@@ -506,6 +505,10 @@ public class SurefireReportGenerator
         sink.section1_();
     }
 
+
+    private String toHtmlId(String id){
+        return id.replace(".", "_");
+    }
     private void constructFailureDetails( Sink sink, ResourceBundle bundle, List failureList )
     {
         Iterator failIter = failureList.iterator();
@@ -514,13 +517,11 @@ public class SurefireReportGenerator
         {
             sink.section1();
             sink.sectionTitle1();
+            sink.text( bundle.getString( "report.surefire.label.failuredetails" ) );
+            sink.sectionTitle1_();
 
             sinkAnchor( sink, "Failure_Details" );
 
-            sink.text( bundle.getString( "report.surefire.label.failuredetails" ) );
-
-            sink.sectionTitle1_();
-
             constructHotLinks( sink, bundle );
 
             sinkLineBreak( sink );
@@ -591,7 +592,9 @@ public class SurefireReportGenerator
                     sinkCell( sink, "" );
 
                     sink.tableCell();
-                    sink.rawText( "  <div id=\"" + tCase.getName() + "error\" >" );
+                    SinkEventAttributeSet atts = new SinkEventAttributeSet();
+                    atts.addAttribute( SinkEventAttributes.ID, tCase.getName() + "error" );
+                    sink.unknown( "div", new Object[]{new Integer( HtmlMarkup.TAG_TYPE_START )}, atts );
 
                     if ( xrefLocation != null )
                     {
@@ -607,7 +610,7 @@ public class SurefireReportGenerator
                     {
                         sink.link_();
                     }
-                    sink.rawText( "</div>" );
+                    sink.unknown( "div", new Object[]{new Integer( HtmlMarkup.TAG_TYPE_END )}, null );
 
                     sink.tableCell_();
 
@@ -646,21 +649,21 @@ public class SurefireReportGenerator
     {
         if ( !testSuites.isEmpty() )
         {
-            sink.section2();
+            sink.paragraph();
 
-            sink.rawText( "[" );
+            sink.text( "[" );
             sinkLink( sink, bundle.getString( "report.surefire.label.summary" ), "#Summary" );
-            sink.rawText( "]" );
+            sink.text( "]" );
 
-            sink.rawText( " [" );
+            sink.text( " [" );
             sinkLink( sink, bundle.getString( "report.surefire.label.packagelist" ), "#Package_List" );
-            sink.rawText( "]" );
+            sink.text( "]" );
 
-            sink.rawText( " [" );
+            sink.text( " [" );
             sinkLink( sink, bundle.getString( "report.surefire.label.testcases" ), "#Test_Cases" );
-            sink.rawText( "]" );
+            sink.text( "]" );
 
-            sink.section2_();
+            sink.paragraph_();
         }
     }
 
@@ -730,4 +733,31 @@ public class SurefireReportGenerator
         sink.anchor( anchor );
         sink.anchor_();
     }
+
+    private static String javascriptToggleDisplayCode()
+    {
+        final StringBuffer str = new StringBuffer( 64 );
+
+        // the javascript code is emitted within a commented CDATA section
+        // so we have to start with a newline and comment the CDATA closing in the end
+        str.append( "\n" );
+        str.append( "function toggleDisplay(elementId) {\n" );
+        str.append( " var elm = document.getElementById(elementId + 'error');\n" );
+        str.append( " if (elm && typeof elm.style != \"undefined\") {\n" );
+        str.append( " if (elm.style.display == \"none\") {\n" );
+        str.append( " elm.style.display = \"\";\n" );
+        str.append( " document.getElementById(elementId + 'off').style.display = \"none\";\n" );
+        str.append( " document.getElementById(elementId + 'on').style.display = \"inline\";\n" );
+        str.append( " }" );
+        str.append( " else if (elm.style.display == \"\") {" );
+        str.append( " elm.style.display = \"none\";\n" );
+        str.append( " document.getElementById(elementId + 'off').style.display = \"inline\";\n" );
+        str.append( " document.getElementById(elementId + 'on').style.display = \"none\";\n" );
+        str.append( " } \n" );
+        str.append( " } \n" );
+        str.append( " }\n" );
+        str.append( "//" );
+
+        return str.toString();
+    }
 }
