@@ -23,14 +23,15 @@ package org.apache.maven.surefire.report;
  * Brief format console reporter.
  *
  * @author <a href="mailto:jruiz@exist.com">Johnny R. Ruiz III</a>
- * @version $Id: BriefConsoleReporter.java 510866 2007-02-23 08:13:49Z brett $
+ * @version $Id: BriefConsoleReporter.java 1098758 2011-05-02 19:27:22Z krosenvold $
  */
 
 public class BriefConsoleReporter
     extends AbstractConsoleReporter
 {
-    public BriefConsoleReporter( Boolean trimStackTrace )
+
+    public BriefConsoleReporter( boolean trimStackTrace )
     {
-        super( BRIEF, trimStackTrace );
+        super( trimStackTrace, BRIEF );
     }
 }
