@@ -25,13 +25,19 @@ import java.io.File;
  * Brief format file reporter.
  *
  * @author <a href="mailto:jruiz@exist.com">Johnny R. Ruiz III</a>
- * @version $Id: BriefFileReporter.java 510866 2007-02-23 08:13:49Z brett $
+ * @version $Id: BriefFileReporter.java 1143207 2011-07-05 21:37:57Z pgier $
  */
 public class BriefFileReporter
     extends AbstractFileReporter
 {
-    public BriefFileReporter( File reportsDirectory, Boolean trimStackTrace )
+
+    public BriefFileReporter( boolean trimStackTrace, File reportsDirectory )
     {
-        super( reportsDirectory, BRIEF, trimStackTrace );
+        super( trimStackTrace, BRIEF, reportsDirectory );
+    }
+    
+    public BriefFileReporter( boolean trimStackTrace, File reportsDirectory, String reportNameSuffix )
+    {
+        super( trimStackTrace, BRIEF, reportsDirectory, reportNameSuffix );
     }
 }
