@@ -23,13 +23,14 @@ package org.apache.maven.surefire.report;
  * Console reporter.
  *
  * @author <a href="mailto:jruiz@exist.com">Johnny R. Ruiz III</a>
- * @version $Id: ConsoleReporter.java 510866 2007-02-23 08:13:49Z brett $
+ * @version $Id: ConsoleReporter.java 1098758 2011-05-02 19:27:22Z krosenvold $
  */
 public class ConsoleReporter
     extends AbstractConsoleReporter
 {
-    public ConsoleReporter( Boolean trimStackTrace )
+
+    public ConsoleReporter( boolean trimStackTrace )
     {
-        super( SUMMARY, trimStackTrace );
+        super( trimStackTrace, SUMMARY );
     }
 }
