@@ -23,13 +23,14 @@ package org.apache.maven.surefire.report;
  * Detailed console reporter.
  *
  * @author <a href="mailto:jruiz@exist.com">Johnny R. Ruiz III</a>
- * @version $Id: DetailedConsoleReporter.java 510866 2007-02-23 08:13:49Z brett $
+ * @version $Id: DetailedConsoleReporter.java 1098758 2011-05-02 19:27:22Z krosenvold $
  */
 public class DetailedConsoleReporter
     extends AbstractConsoleReporter
 {
-    public DetailedConsoleReporter( Boolean trimStackTrace )
+
+    public DetailedConsoleReporter( boolean trimStackTrace )
     {
-        super( PLAIN, trimStackTrace );
+        super( trimStackTrace, PLAIN );
     }
 }
