@@ -25,13 +25,19 @@ import java.io.File;
  * Text file reporter.
  *
  * @author <a href="mailto:jruiz@exist.com">Johnny R. Ruiz III</a>
- * @version $Id: FileReporter.java 510866 2007-02-23 08:13:49Z brett $
+ * @version $Id: FileReporter.java 1143207 2011-07-05 21:37:57Z pgier $
  */
 public class FileReporter
     extends AbstractFileReporter
 {
-    public FileReporter( File reportsDirectory, Boolean trimStackTrace )
+
+    public FileReporter( boolean trimStackTrace, File reportsDirectory )
     {
-        super( reportsDirectory, PLAIN, trimStackTrace );
+        super( trimStackTrace, PLAIN, reportsDirectory );
+    }
+    
+    public FileReporter( boolean trimStackTrace, File reportsDirectory, String reportNamePrefix )
+    {
+        super( trimStackTrace, PLAIN, reportsDirectory, reportNamePrefix);
     }
 }
