@@ -19,7 +19,7 @@ package org.apache.maven.surefire.report;
  * under the License.
  */
 
-import org.apache.maven.surefire.util.NestedCheckedException;
+import org.apache.maven.surefire.util.NestedRuntimeException;
 
 /**
  * Exception occurring during report generation.
@@ -27,7 +27,7 @@ import org.apache.maven.surefire.util.NestedCheckedException;
  * @author <a href="mailto:brett@apache.org">Brett Porter</a>
  */
 public class ReporterException
-    extends NestedCheckedException
+    extends NestedRuntimeException
 {
     public ReporterException( String message, Exception nested )
     {
